/*
Example do-file for the Stata 15 stintreg command
Accompanying a blog post written for Timberlake Consultants
  (timberlake.co.uk) by Robert Grant of BayesCamp (bayescamp.com)
*/

import delimited using "retraction.csv", clear
label define txlab 0 "Radio" 1 "Radio + Chemo"
label values treatment txlab

// visualise the intervals
sort treatment start
gen index = _n
gen pseudoend = end
qui summ end
local maxend=r(max)
replace pseudoend = `maxend' if end==.
twoway (scatter start index, mcol(navy)) ///
       (scatter end index, mcol(cranberry)) ///
	   (rspike start pseudoend index, lcol(gs7)), ///
	   scheme(s1color) xlabel(25 "Radio" 75 "Radio+Chemo") xtitle("") ///
	   ytitle("Follow-up (days)") ///
	   legend(order(1 "Last appointment without retraction" ///
	                2 "First appointment with retraction") ///
	          cols(1))

// fit a naive streg (Weibull) with the start time
gen naive = (end!=.)
stset start, failure(naive)
streg treatment, distribution(weibull)
// this shows a strong and significant detrimental effect of chemotherapy

// fit a naive streg (Weibull) with the midpoint of start and end time
gen naivetime = (start+end)/2
stset naivetime, failure(naive)
streg treatment, distribution(weibull)
// this shows a negligible and non-significant difference.

// Which can we trust??!

// A more principled interval-censored analysis
stset, clear
// (note that stset is ignored by stintreg)
stintreg treatment, interval(start end) distribution(weibull)


